summaryrefslogtreecommitdiffstats
path: root/qmake
diff options
context:
space:
mode:
authorFrans Englich <frans.englich@nokia.com>2009-10-19 14:51:33 (GMT)
committerFrans Englich <frans.englich@nokia.com>2009-10-21 08:23:11 (GMT)
commita6af1538ea53408399fb29870a4ef16a92c7893a (patch)
tree650647006e6f13dfdde00fa78421c966360a6f54 /qmake
parentefd2bbd159bb4810ed828c842f459e6fcb8eb783 (diff)
downloadQt-a6af1538ea53408399fb29870a4ef16a92c7893a.zip
Qt-a6af1538ea53408399fb29870a4ef16a92c7893a.tar.gz
Qt-a6af1538ea53408399fb29870a4ef16a92c7893a.tar.bz2
Switch from *-armv5 to *-armv6.
Change from armv5 to armv6 by default. This updates documentation, the convenience scripts, and the Raptor/abld qmake generator to use armv6 instead. Task-number: QTBUG-4891 Reviewed-by: Jason Barron
Diffstat (limited to 'qmake')
-rw-r--r--qmake/generators/symbian/symmake_abld.cpp6
-rw-r--r--qmake/generators/symbian/symmake_sbsv2.cpp6
2 files changed, 6 insertions, 6 deletions
diff --git a/qmake/generators/symbian/symmake_abld.cpp b/qmake/generators/symbian/symmake_abld.cpp
index 4d1673b..692ead7 100644
--- a/qmake/generators/symbian/symmake_abld.cpp
+++ b/qmake/generators/symbian/symmake_abld.cpp
@@ -224,8 +224,8 @@ void SymbianAbldMakefileGenerator::writeWrapperMakefile(QFile& wrapperFile, bool
t << "first: default" << endl;
if (debugPlatforms.contains("winscw"))
t << "default: debug-winscw";
- else if (debugPlatforms.contains("armv5"))
- t << "default: debug-armv5";
+ else if (debugPlatforms.contains("armv6"))
+ t << "default: debug-armv6";
else if (debugPlatforms.size())
t << "default: debug-" << debugPlatforms.first();
else
@@ -259,7 +259,7 @@ void SymbianAbldMakefileGenerator::writeWrapperMakefile(QFile& wrapperFile, bool
}
t << endl;
// For more specific builds, targets are in this form: build-platform, e.g. release-armv5
foreach(QString item, debugPlatforms) {
t << "debug-" << item << ": $(ABLD)" << endl;
t << "\t$(ABLD)" << testClause << " build " << item << " udeb" << endl;
@@ -259,7 +259,7 @@ void SymbianAbldMakefileGenerator::writeWrapperMakefile(QFile& wrapperFile, bool
}
t << endl;
- // For more specific builds, targets are in this form: build-platform, e.g. release-armv5
+ // For more specific builds, targets are in this form: build-platform, e.g. release-armv6
foreach(QString item, debugPlatforms) {
t << "debug-" << item << ": $(ABLD)" << endl;
diff --git a/qmake/generators/symbian/symmake_sbsv2.cpp b/qmake/generators/symbian/symmake_sbsv2.cpp
index cad2736..bcb93af 100644
--- a/qmake/generators/symbian/symmake_sbsv2.cpp
+++ b/qmake/generators/symbian/symmake_sbsv2.cpp
@@ -150,8 +150,8 @@ void SymbianSbsv2MakefileGenerator::writeWrapperMakefile(QFile& wrapperFile, boo
t << "first: default" << endl;
if (debugPlatforms.contains("winscw"))
t << "default: debug-winscw";
- else if (debugPlatforms.contains("armv5"))
- t << "default: debug-armv5";
+ else if (debugPlatforms.contains("armv6"))
+ t << "default: debug-armv6";
else if (debugPlatforms.size())
t << "default: debug-" << debugPlatforms.first();
else
@@ -182,7 +182,7 @@ void SymbianSbsv2MakefileGenerator::writeWrapperMakefile(QFile& wrapperFile, boo
}
t << endl;
// For more specific builds, targets are in this form: build-platform, e.g. release-armv5
foreach(QString item, debugPlatforms) {
t << "debug-" << item << ": " << BLD_INF_FILENAME << endl;
t << "\t$(SBS) -c " << item << "_udeb" << testClause << endl;
@@ -182,7 +182,7 @@ void SymbianSbsv2MakefileGenerator::writeWrapperMakefile(QFile& wrapperFile, boo
}
t << endl;
- // For more specific builds, targets are in this form: build-platform, e.g. release-armv5
+ // For more specific builds, targets are in this form: build-platform, e.g. release-armv6
foreach(QString item, debugPlatforms) {
t << "debug-" << item << ": " << BLD_INF_FILENAME << endl;